@@ -60,8 +60,7 @@ void Tracer::processArgs()
 }
 Tracer::Tracer(std::string_view appName,
                const std::shared_ptr<Core>& core,
-               const FederateInfo& fedInfo):
-    App(appName, core, fedInfo)
+               const FederateInfo& fedInfo): App(appName, core, fedInfo)
 {
     initialSetup();
 }
