@@ -15,9 +15,11 @@ SPDX-License-Identifier: BSD-3-Clause
 #include "testFixtures.hpp"
 
 #include <algorithm>
+#include <fstream>
 #include <future>
 #include <gtest/gtest.h>
 #include <numeric>
+#include <sstream>
 
 /** these test cases test out the value federates with some additional tests
  */
@@ -579,7 +581,8 @@ TEST_F(valuefed_add_tests_ci_skip, test_move_calls)
 static constexpr const char* config_files[] = {"example_value_fed.json",
                                                "example_value_fed.toml",
                                                "example_value_fed_helics1.json",
-                                               "example_value_fed_helics2.json"};
+                                               "example_value_fed_helics2.json",
+                                               "example_value_fed_helics_broker.json"};
 
 class valuefed_add_configfile_tests:
     public ::testing::TestWithParam<const char*>,
@@ -615,6 +618,40 @@ TEST_P(valuefed_add_configfile_tests, file_load)
     vFed.disconnect();
 }
 
+TEST_P(valuefed_add_configfile_tests, file_load_as_string)
+{
+    std::ifstream file(std::string(TEST_DIR) + GetParam());
+    std::stringstream buffer;
+    buffer << file.rdbuf();
+
+    helics::ValueFederate vFed(buffer.str());
+
+    EXPECT_EQ(vFed.getName(), "valueFed");
+
+    EXPECT_EQ(vFed.getInputCount(), 3);
+    EXPECT_EQ(vFed.getPublicationCount(), 2);
+    auto& inp1 = vFed.getInput("pubshortcut");
+
+    auto key = vFed.getTarget(inp1);
+    EXPECT_EQ(key, "fedName/pub2");
+
+    EXPECT_EQ(inp1.getInfo(), "this is an information string for use by the application");
+    auto pub2name = vFed.getPublication(1).getName();
+    EXPECT_EQ(pub2name, "valueFed/pub2");
+    // test the info from a file
+    EXPECT_EQ(vFed.getPublication(0).getInfo(),
+              "this is an information string for use by the application");
+
+    EXPECT_EQ(vFed.getInput(2).getName(), "valueFed/ipt2");
+
+    EXPECT_EQ(vFed.query("global_value", "global1"), "this is a global1 value");
+    EXPECT_EQ(vFed.query("global_value", "global2"), "this is another global value");
+
+    auto& pub = vFed.getPublication("pub1");
+    EXPECT_EQ(pub.getUnits(), "m");
+    vFed.disconnect();
+}
+
 TEST(valuefed_json_tests, file_loadb)
 {
     helics::ValueFederate vFed(std::string(TEST_DIR) + "example_value_fed_testb.json");
